@@ -45,6 +45,7 @@
       {"FALSE",1,0,_INT_BOOLEAN,T_NUMBER},
       {"FAUX",1,0,_INT_BOOLEAN,T_NUMBER},
       {"FROM",0,0,0,T_FROM},
+      {"False",1,0,_INT_BOOLEAN,T_NUMBER},
       {"Func",0,0,0,TI_PRGM},
       {"GLOBAL",0,1,0,T_LOCAL},
       {"IFERR",0,0,0,T_IFERR},
@@ -64,18 +65,22 @@
       {"TRUE",1,1,_INT_BOOLEAN,T_NUMBER},
       {"TRY",0,0,0,T_TRY},
       {"Then",0,0,0,T_THEN},
+      {"True",1,1,_INT_BOOLEAN,T_NUMBER},
       {"Try",0,0,0,TI_TRY},
       {"UNTIL",0,0,0,T_UNTIL},
       {"VRAI",1,1,_INT_BOOLEAN,T_NUMBER},
       {"adaptive"         ,1,_ADAPTIVE , _INT_PLOT ,T_NUMBER},
       {"algebraic"              ,0, _SYMB, _INT_TYPE, T_TYPE_ID},
       {"args",1,0,0,T_ARGS},
+      {"arrow_line"         ,1, _CAP_FLAT_LINE, _INT_COLOR ,T_NUMBER},
       {"axes"         ,1,_AXES , _INT_PLOT ,T_NUMBER},
       {"axesfont"         ,1,_AXESFONT , _INT_PLOT ,T_NUMBER},
       {"bareiss"         ,1, _BAREISS, _INT_SOLVER,T_NUMBER},
       {"base"         ,1,_BASE , _INT_MAPLECONVERSION ,T_NUMBER},
       {"begin",0,0,0,T_BLOC_BEGIN},
       {"bisection_solver"         ,1, _BISECTION_SOLVER, _INT_SOLVER,T_NUMBER},
+      {"blanc"         ,1, _WHITE, _INT_COLOR ,T_NUMBER},
+      {"bleu"         ,1, _BLUE, _INT_COLOR ,T_NUMBER},
       {"brent_solver"         ,1, _BRENT_SOLVER, _INT_SOLVER,T_NUMBER},
       {"by",1,0,0,T_BY},
       {"cap_flat_line"         ,1, _CAP_FLAT_LINE, _INT_COLOR ,T_NUMBER},
@@ -83,11 +88,12 @@
       {"cap_square_line"         ,1, _CAP_SQUARE_LINE, _INT_COLOR ,T_NUMBER},
       {"case",0,0,0,T_CASE},
       {"catch",0,0,0,T_CATCH},
-      {"complex"               ,0, _CPLX, _INT_TYPE, T_TYPE_ID},
+      // {"complex"               ,0, _CPLX, _INT_TYPE, T_TYPE_ID},
       {"confrac"         ,1,_CONFRAC , _INT_MAPLECONVERSION ,T_NUMBER},
       {"continue",0,0,0,T_CONTINUE},
       {"coords"         ,1, _COORDS, _INT_PLOT ,T_NUMBER},
       {"cross_point"         ,1, 0  , _INT_COLOR ,T_NUMBER},
+      {"cyan"         ,1, _CYAN, _INT_COLOR ,T_NUMBER},
       {"dash_line"         ,1, _DASH_LINE, _INT_COLOR ,T_NUMBER},
       {"dashdot_line"         ,1, _DASHDOT_LINE, _INT_COLOR ,T_NUMBER},
       {"dashdotdot_line"         ,1, _DASHDOTDOT_LINE, _INT_COLOR ,T_NUMBER},
@@ -125,6 +131,7 @@
       {"epaisseur_point_8"         ,1, _POINT_WIDTH_8 , _INT_COLOR ,T_NUMBER},
       {"esac",0,0,0,T_ENDCASE},
       {"expln"         ,1,_EXPLN , _INT_MAPLECONVERSION ,T_NUMBER},
+      {"expression"         ,0, _SYMBOL, _INT_TYPE ,T_TYPE_ID},
       {"faddeev"         ,1, _FADEEV, _INT_SOLVER,T_NUMBER},
       {"fadeev"         ,1, _FADEEV, _INT_SOLVER,T_NUMBER},
       {"false",1,0,_INT_BOOLEAN,T_NUMBER},
@@ -132,6 +139,7 @@
       {"faux",1,0,_INT_BOOLEAN,T_NUMBER},
       {"ffaire",0,2,0,T_BLOC_END},
       {"ffonction",0,3,0,T_BLOC_END},
+      {"ffunction",0,3,0,T_BLOC_END},
       {"fi",0,4,0,T_BLOC_END},
       {"filled"         ,1, _FILL_POLYGON, _INT_COLOR ,T_NUMBER},
       {"float"                ,0, _DOUBLE_, _INT_TYPE, T_TYPE_ID},
@@ -142,7 +150,7 @@
       {"fsi",0,4,0,T_BLOC_END},
       {"ftantque",0,8,0,T_BLOC_END},
       {"fullparfrac"         ,1,_FULLPARFRAC , _INT_MAPLECONVERSION ,T_NUMBER},
-      {"func",0,0,0,TI_PRGM},
+      {"func"                ,0, _FUNC, _INT_TYPE, T_TYPE_ID},
       {"function",0,0,0,T_PROC},
       {"gauss15"         ,1, _GAUSS15, _INT_SOLVER,T_NUMBER},
       {"gl_ambient"       ,1,_GL_AMBIENT , _INT_PLOT ,T_NUMBER},
@@ -219,11 +227,13 @@
       {"hybridj_solver"         ,1, _HYBRIDJ_SOLVER, _INT_SOLVER,T_NUMBER},
       {"hybrids_solver"         ,1, _HYBRIDS_SOLVER, _INT_SOLVER,T_NUMBER},
       {"hybridsj_solver"         ,1, _HYBRIDSJ_SOLVER, _INT_SOLVER,T_NUMBER},
+      {"identifier"            ,0, _IDNT, _INT_TYPE, T_TYPE_ID},
       {"in",0,0,0,T_IN},
       {"integer"               ,0, _ZINT, _INT_TYPE, T_TYPE_ID},
       {"intersect",0,0,0,T_INTERSECT},
       {"invisible_point"         ,1, _POINT_INVISIBLE , _INT_COLOR ,T_NUMBER},
       {"jacobi_decomp"         ,1, _JACOBI_DECOMP, _INT_SOLVER,T_NUMBER},
+      {"jaune"         ,1, _YELLOW, _INT_COLOR ,T_NUMBER},
       {"jusqu_a",0,0,0,T_UNTIL},
       {"jusqua",0,0,0,T_UNTIL},
       {"keep_pivot"         ,1, _KEEP_PIVOT, _INT_SOLVER,T_NUMBER},
@@ -251,6 +261,38 @@
       {"linestyle"         ,1, _LINESTYLE, _INT_PLOT ,T_NUMBER},
       {"local",0,0,0,T_LOCAL},
       {"localbloc",0,0,0,T_LOCALBLOC},
+      {"lp_assume"               ,0, _LP_ASSUME, _INT_MAPLECONVERSION, T_TYPE_ID},
+      {"lp_best_projection",0,    _LP_BEST_PROJECTION, _INT_MAPLECONVERSION,T_TYPE_ID},
+      {"lp_binary"               ,0, _LP_BINARY, _INT_MAPLECONVERSION, T_TYPE_ID},
+      {"lp_binaryvariables"               ,0, _LP_BINARYVARIABLES, _INT_MAPLECONVERSION, T_TYPE_ID},
+      {"lp_breadthfirst",0,    _LP_BREADTHFIRST, _INT_MAPLECONVERSION,T_TYPE_ID},
+      {"lp_depthfirst",0,    _LP_DEPTHFIRST, _INT_MAPLECONVERSION,T_TYPE_ID},
+      {"lp_depthlimit"               ,0, _LP_DEPTHLIMIT, _INT_MAPLECONVERSION, T_TYPE_ID},
+      {"lp_firstfractional",0,    _LP_FIRSTFRACTIONAL, _INT_MAPLECONVERSION,T_TYPE_ID},
+      {"lp_gap_tolerance",0,    _LP_GAP_TOLERANCE, _INT_MAPLECONVERSION,T_TYPE_ID},
+      {"lp_hybrid",0,    _LP_HYBRID, _INT_MAPLECONVERSION,T_TYPE_ID},
+      {"lp_initialpoint"               ,0, _LP_INITIAL_POINT, _INT_MAPLECONVERSION, T_TYPE_ID},
+      {"lp_integer"               ,0, _LP_INTEGER, _INT_MAPLECONVERSION, T_TYPE_ID},
+      {"lp_integertolerance"               ,0, _LP_INTEGER_TOLERANCE, _INT_MAPLECONVERSION, T_TYPE_ID},
+      {"lp_integervariables"               ,0, _LP_INTEGERVARIABLES, _INT_MAPLECONVERSION, T_TYPE_ID},
+      {"lp_interiorpoint"               ,0, _LP_INTERIOR_POINT, _INT_MAPLECONVERSION, T_TYPE_ID},
+      {"lp_iteration_limit",0,    _LP_ITERATION_LIMIT, _INT_MAPLECONVERSION,T_TYPE_ID},
+      {"lp_lastfractional",0,    _LP_LASTFRACTIONAL, _INT_MAPLECONVERSION,T_TYPE_ID},
+      {"lp_max_cuts",0,    _LP_MAX_CUTS, _INT_MAPLECONVERSION,T_TYPE_ID},
+      {"lp_maximize"               ,0, _LP_MAXIMIZE, _INT_MAPLECONVERSION, T_TYPE_ID},
+      {"lp_method"               ,0, _LP_METHOD, _INT_MAPLECONVERSION, T_TYPE_ID},
+      {"lp_mostfractional",0,    _LP_MOSTFRACTIONAL, _INT_MAPLECONVERSION,T_TYPE_ID},
+      {"lp_nodelimit"               ,0, _LP_NODE_LIMIT, _INT_MAPLECONVERSION, T_TYPE_ID},
+      {"lp_nodeselect",0,    _LP_NODESELECT, _INT_MAPLECONVERSION,T_TYPE_ID},
+      {"lp_nonnegative"               ,0, _LP_NONNEGATIVE, _INT_MAPLECONVERSION, T_TYPE_ID},
+      {"lp_nonnegint"               ,0, _LP_NONNEGINT, _INT_MAPLECONVERSION, T_TYPE_ID},
+      {"lp_pseudocost",0,    _LP_PSEUDOCOST, _INT_MAPLECONVERSION,T_TYPE_ID},
+      {"lp_simplex"               ,0, _LP_SIMPLEX, _INT_MAPLECONVERSION, T_TYPE_ID},
+      {"lp_time_limit",0,    _LP_TIME_LIMIT, _INT_MAPLECONVERSION,T_TYPE_ID},
+      {"lp_variables"               ,0, _LP_VARIABLES, _INT_MAPLECONVERSION, T_TYPE_ID},
+      {"lp_varselect",0,    _LP_VARSELECT, _INT_MAPLECONVERSION,T_TYPE_ID},
+      {"lp_verbose",0,    _LP_VERBOSE, _INT_MAPLECONVERSION,T_TYPE_ID},
+      {"magenta"         ,1, _MAGENTA, _INT_COLOR ,T_NUMBER},
       {"middle_point"         ,1, _POINT_MILIEU, _INT_SOLVER,T_NUMBER},
       {"minor_det"         ,1, _MINOR_DET, _INT_SOLVER,T_NUMBER},
       {"minus",0,0,0,T_MINUS},
@@ -259,6 +301,12 @@
       {"newton_solver"         ,1, _NEWTON_SOLVER, _INT_SOLVER,T_NUMBER},
       {"newtonj_solver"         ,1, _NEWTONJ_SOLVER, _INT_SOLVER,T_NUMBER},
       {"next",0,0,0,T_CONTINUE},
+      {"nlp_initialpoint",0,    _NLP_INITIALPOINT, _INT_MAPLECONVERSION,T_TYPE_ID},
+      {"nlp_iterationlimit",0,    _NLP_ITERATIONLIMIT, _INT_MAPLECONVERSION,T_TYPE_ID},
+      {"nlp_maximize",0,    _NLP_MAXIMIZE, _INT_MAPLECONVERSION,T_TYPE_ID},
+      {"nlp_nonnegative",0,    _NLP_NONNEGATIVE, _INT_MAPLECONVERSION,T_TYPE_ID},
+      {"nlp_precision",0,    _NLP_PRECISION, _INT_MAPLECONVERSION,T_TYPE_ID},
+      {"noir"         ,1, _BLACK, _INT_COLOR ,T_NUMBER},
       {"nonnegint"               ,0, _NONNEGINT, _INT_MAPLECONVERSION, T_TYPE_ID},
       {"nonposint"               ,0, _NONPOSINT, _INT_MAPLECONVERSION, T_TYPE_ID},
       {"nstep"         ,1, _NSTEP , _INT_PLOT ,T_NUMBER},
@@ -306,6 +354,7 @@
       {"right_rectangle"         ,1, _RECTANGLE_DROIT, _INT_SOLVER,T_NUMBER},
       {"rombergm"         ,1, _ROMBERGM, _INT_SOLVER,T_NUMBER},
       {"rombergt"         ,1, _ROMBERGT, _INT_SOLVER,T_NUMBER},
+      {"rouge"         ,1, _RED, _INT_COLOR ,T_NUMBER},
       {"rur"         ,1,_RUR_REVLEX , _INT_GROEBNER ,T_NUMBER},
       {"sample"         ,1, _SAMPLE, _INT_PLOT ,T_NUMBER},
       {"sans_factoriser"         ,1, _UNFACTORED, _INT_SOLVER,T_NUMBER},
@@ -345,6 +394,7 @@
       {"until",0,0,0,T_UNTIL},
       {"ustep"         ,1, _USTEP , _INT_PLOT ,T_NUMBER},
       {"var",0,0,0,T_LOCAL},
+      {"vert"         ,1, _GREEN, _INT_COLOR ,T_NUMBER},
       {"view"         ,1, _VIEW, _INT_PLOT ,T_NUMBER},
       {"vrai",1,1,_INT_BOOLEAN,T_NUMBER},
       {"vstep"         ,1, _VSTEP , _INT_PLOT ,T_NUMBER},
